@@ -7,6 +7,7 @@ import os
 import re
 import datetime
 import pathlib
+import oecommon_getsize
 
 
 def fix_block_encoding_errors(block):
@@ -103,6 +104,13 @@ def replace_string_in_file(path, regex, replaced):
         print("Warning! %s not found" % path)
 
 
+def get_directory_size(path):
+    if os.path.isdir(path):
+        size = oecommon_getsize.get_directory_size(path)
+        return size
+    return 0
+
+
 class Logger:
     def __init__(self, to_console=True, file=None):
         self._to_console = to_console
